==> jc-1.4.0.tar.gz: soot/jimple/parser/node/X2PCatchClause.h <==
// public final class soot.jimple.parser.node.X2PCatchClause

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b07ef278be22763e soot_jimple_parser_node_X2PCatchClause
// @dep_class 628a950f9830980 soot_jimple_parser_node_XPCatchClause

// header file dependencies
// @dep_header soot_jimple_parser_node_XPCatchClause

#include "soot/jimple/parser/node/XPCatchClause.h"

#ifndef _JC_soot_jimple_parser_node_X2PCatchClause_H_
#define _JC_soot_jimple_parser_node_X2PCatchClause_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PCatchClause$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$sub_refs	_jc_soot_jimple_parser_node_X2PCatchClause$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$sub_nonrefs	_jc_soot_jimple_parser_node_X2PCatchClause$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$refs	_jc_soot_jimple_parser_node_X2PCatchClause$refs;
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$nonrefs	_jc_soot_jimple_parser_node_X2PCatchClause$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$object	_jc_soot_jimple_parser_node_X2PCatchClause$object;

typedef const struct _jc_soot_jimple_parser_node_X2PCatchClause$vmethods	_jc_soot_jimple_parser_node_X2PCatchClause$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PCatchClause$vtable	_jc_soot_jimple_parser_node_X2PCatchClause$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PCatchClause$vtype	_jc_soot_jimple_parser_node_X2PCatchClause$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *);
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$_init$90e03b6139395ebf(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_PCatchClause$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PCatchClause$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *);
extern struct _jc_soot_jimple_parser_node_PCatchClause$object *_jc_soot_jimple_parser_node_X2PCatchClause$method$getPCatchClause$ece57ca6b428aefe(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *);
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$setPCatchClause$e08def68f99555d1(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_PCatchClause$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PCatchClause$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$getPCatchClause$ece57ca6b428aefe;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$setPCatchClause$e08def68f99555d1;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PCatchClause$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *);
	struct _jc_soot_jimple_parser_node_PCatchClause$object	*(*getPCatchClause$ece57ca6b428aefe)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPCatchClause$e08def68f99555d1)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_PCatchClause$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PCatchClause$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPCatchClause$vmethods	soot_jimple_parser_node_XPCatchClause;
	_jc_soot_jimple_parser_node_X2PCatchClause$vmethods	soot_jimple_parser_node_X2PCatchClause;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PCatchClause$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PCatchClause$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PCatchClause$sub_refs {
	struct _jc_soot_jimple_parser_node_PCatchClause$object	*__5fpCatchClause__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PCatchClause$refs {
    _jc_soot_jimple_parser_node_X2PCatchClause$sub_refs	soot_jimple_parser_node_X2PCatchClause;
    _jc_soot_jimple_parser_node_XPCatchClause$sub_refs	soot_jimple_parser_node_XPCatchClause;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PCatchClause$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PCatchClause$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPCatchClause$sub_nonrefs	soot_jimple_parser_node_XPCatchClause;
    _jc_soot_jimple_parser_node_X2PCatchClause$sub_nonrefs	soot_jimple_parser_node_X2PCatchClause;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PCatchClause$object {
	_jc_soot_jimple_parser_node_X2PCatchClause$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PCatchClause$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PCatchClause$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PCatchClause$vtype _jc_soot_jimple_parser_node_X2PCatchClause$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PCatchClause, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PCatchClause$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PCatchClause_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/X2PCatchClause.h <==
// public final class soot.jimple.parser.node.X2PCatchClause

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b07ef278be22763e soot_jimple_parser_node_X2PCatchClause
// @dep_class 628a950f9830980 soot_jimple_parser_node_XPCatchClause

// header file dependencies
// @dep_header soot_jimple_parser_node_XPCatchClause

#include "soot/jimple/parser/node/XPCatchClause.h"

#ifndef _JC_soot_jimple_parser_node_X2PCatchClause_H_
#define _JC_soot_jimple_parser_node_X2PCatchClause_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PCatchClause$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$sub_refs	_jc_soot_jimple_parser_node_X2PCatchClause$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$sub_nonrefs	_jc_soot_jimple_parser_node_X2PCatchClause$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$refs	_jc_soot_jimple_parser_node_X2PCatchClause$refs;
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$nonrefs	_jc_soot_jimple_parser_node_X2PCatchClause$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PCatchClause$object	_jc_soot_jimple_parser_node_X2PCatchClause$object;

typedef const struct _jc_soot_jimple_parser_node_X2PCatchClause$vmethods	_jc_soot_jimple_parser_node_X2PCatchClause$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PCatchClause$vtable	_jc_soot_jimple_parser_node_X2PCatchClause$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PCatchClause$vtype	_jc_soot_jimple_parser_node_X2PCatchClause$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$_init$90e03b6139395ebf(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_PCatchClause$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PCatchClause$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PCatchClause$object *_jc_soot_jimple_parser_node_X2PCatchClause$method$getPCatchClause$ece57ca6b428aefe(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PCatchClause$method$setPCatchClause$e08def68f99555d1(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_PCatchClause$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PCatchClause$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$getPCatchClause$ece57ca6b428aefe;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$setPCatchClause$e08def68f99555d1;
extern _jc_method _jc_soot_jimple_parser_node_X2PCatchClause$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PCatchClause$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PCatchClause$object	*(*getPCatchClause$ece57ca6b428aefe)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPCatchClause$e08def68f99555d1)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *, struct _jc_soot_jimple_parser_node_PCatchClause$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PCatchClause$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PCatchClause$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPCatchClause$vmethods	soot_jimple_parser_node_XPCatchClause;
	_jc_soot_jimple_parser_node_X2PCatchClause$vmethods	soot_jimple_parser_node_X2PCatchClause;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PCatchClause$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PCatchClause$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PCatchClause$sub_refs {
	struct _jc_soot_jimple_parser_node_PCatchClause$object	*__5fpCatchClause__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PCatchClause$refs {
    _jc_soot_jimple_parser_node_X2PCatchClause$sub_refs	soot_jimple_parser_node_X2PCatchClause;
    _jc_soot_jimple_parser_node_XPCatchClause$sub_refs	soot_jimple_parser_node_XPCatchClause;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PCatchClause$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PCatchClause$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPCatchClause$sub_nonrefs	soot_jimple_parser_node_XPCatchClause;
    _jc_soot_jimple_parser_node_X2PCatchClause$sub_nonrefs	soot_jimple_parser_node_X2PCatchClause;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PCatchClause$object {
	_jc_soot_jimple_parser_node_X2PCatchClause$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PCatchClause$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PCatchClause$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PCatchClause$vtype _jc_soot_jimple_parser_node_X2PCatchClause$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PCatchClause, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PCatchClause$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PCatchClause_H_ */
